@@ -1,8 +1,8 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
 #
-nobs.mvmeta <-
-  function (object, ...) {
+`nobs.mvmeta` <-
+function (object, ...) {
 #
 ################################################################################
 # EXTRACTS THE NUMBER OF OBSERVATIONS USED FOR FITTING. USED BY BIC
