@@ -1,5 +1,8 @@
-xpndMat <-
-  function(vech) {
+###
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+#
+`xpndMat` <-
+function(vech) {
 #
 ################################################################################
 #
